# HG changeset patch
# Node ID 807f655da8fa
# Parent  a91d4fc763f4
diff --git a/pidgin/gtkblist.c b/pidgin/gtkblist.c
--- a/pidgin/gtkblist.c
+++ b/pidgin/gtkblist.c
@@ -42,7 +42,7 @@
 #include "pidgin/pidginactiongroup.h"
 #include "pidgin/pidgincellrendererexpander.h"
 #include "pidgin/pidginclosebutton.h"
-#include "pidgin/pidgincontactlist.h"
+#include "pidgin/pidgincontactlistwindow.h"
 #include "pidgin/pidgincore.h"
 #include "pidgin/pidgindebug.h"
 #include "pidgin/pidginmooddialog.h"
@@ -3739,7 +3739,7 @@
 	gtkblist = PIDGIN_BUDDY_LIST(list);
 	priv = pidgin_buddy_list_get_instance_private(gtkblist);
 
-	gtkblist->window = pidgin_contact_list_new();
+	gtkblist->window = pidgin_contact_list_window_new();
 	g_signal_connect(G_OBJECT(gtkblist->window), "focus-in-event",
 			 G_CALLBACK(blist_focus_cb), gtkblist);
 	g_signal_connect(G_OBJECT(gtkblist->window), "focus-out-event",
@@ -3748,7 +3748,7 @@
 	/* the main vbox is already packed and shown via glade, we just need a
 	 * reference to it to pack the rest of our widgets here.
 	 */
-	gtkblist->vbox = pidgin_contact_list_get_vbox(PIDGIN_CONTACT_LIST(gtkblist->window));
+	gtkblist->vbox = pidgin_contact_list_window_get_vbox(PIDGIN_CONTACT_LIST_WINDOW(gtkblist->window));
 
 	g_signal_connect(G_OBJECT(gtkblist->window), "delete_event", G_CALLBACK(gtk_blist_delete_cb), NULL);
 	g_signal_connect(G_OBJECT(gtkblist->window), "visibility_notify_event", G_CALLBACK(gtk_blist_visibility_cb), NULL);
@@ -5258,7 +5258,7 @@
 	GMenu *menu = NULL;
 	GList *l;
 
-	if(gtkblist == NULL || !PIDGIN_IS_CONTACT_LIST(gtkblist->window)) {
+	if(gtkblist == NULL || !PIDGIN_IS_CONTACT_LIST_WINDOW(gtkblist->window)) {
 		return;
 	}
 
@@ -5286,7 +5286,7 @@
 	}
 
 	/* replace the old submenu with a new one */
-	sort_item = pidgin_contact_list_get_menu_sort_item(PIDGIN_CONTACT_LIST(gtkblist->window));
+	sort_item = pidgin_contact_list_window_get_menu_sort_item(PIDGIN_CONTACT_LIST_WINDOW(gtkblist->window));
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(sort_item),
 	                          gtk_menu_new_from_model(G_MENU_MODEL(menu)));
 	g_object_unref(menu);
diff --git a/pidgin/meson.build b/pidgin/meson.build
--- a/pidgin/meson.build
+++ b/pidgin/meson.build
@@ -35,7 +35,7 @@
 	'pidgincolor.c',
 	'pidgincommands.c',
 	'pidginconversationwindow.c',
-	'pidgincontactlist.c',
+	'pidgincontactlistwindow.c',
 	'pidgindebug.c',
 	'pidgindialog.c',
 	'pidginiconname.c',
@@ -108,7 +108,7 @@
 	'pidginclosebutton.h',
 	'pidgincolor.h',
 	'pidginconversationwindow.h',
-	'pidgincontactlist.h',
+	'pidgincontactlistwindow.h',
 	'pidgincore.h',
 	'pidgindialog.h',
 	'pidgindebug.h',
diff --git a/pidgin/pidgincontactlist.c b/pidgin/pidgincontactlistwindow.c
rename from pidgin/pidgincontactlist.c
rename to pidgin/pidgincontactlistwindow.c
--- a/pidgin/pidgincontactlist.c
+++ b/pidgin/pidgincontactlistwindow.c
@@ -20,11 +20,11 @@
  * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
-#include "pidgincontactlist.h"
+#include "pidgincontactlistwindow.h"
 
 #include "pidginactiongroup.h"
 
-struct _PidginContactList {
+struct _PidginContactListWindow {
 	GtkApplicationWindow parent;
 
 	GtkWidget *vbox;
@@ -36,14 +36,14 @@
 	GtkWidget *accounts_menu;
 };
 
-G_DEFINE_TYPE(PidginContactList, pidgin_contact_list,
+G_DEFINE_TYPE(PidginContactListWindow, pidgin_contact_list_window,
               GTK_TYPE_APPLICATION_WINDOW)
 
 /******************************************************************************
  * GObject Implementation
  *****************************************************************************/
 static void
-pidgin_contact_list_init(PidginContactList *contact_list) {
+pidgin_contact_list_window_init(PidginContactListWindow *contact_list) {
 	GSimpleActionGroup *group = NULL;
 
 	gtk_widget_init_template(GTK_WIDGET(contact_list));
@@ -60,7 +60,7 @@
 }
 
 static void
-pidgin_contact_list_class_init(PidginContactListClass *klass) {
+pidgin_contact_list_window_class_init(PidginContactListWindowClass *klass) {
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
 
 	gtk_widget_class_set_template_from_resource(
@@ -68,15 +68,15 @@
 	    "/im/pidgin/Pidgin3/BuddyList/window.ui"
 	);
 
-	gtk_widget_class_bind_template_child(widget_class, PidginContactList, vbox);
-
-	gtk_widget_class_bind_template_child(widget_class, PidginContactList,
+	gtk_widget_class_bind_template_child(widget_class, PidginContactListWindow,
+	                                     vbox);
+	gtk_widget_class_bind_template_child(widget_class, PidginContactListWindow,
 	                                     menu_bar);
-	gtk_widget_class_bind_template_child(widget_class, PidginContactList,
+	gtk_widget_class_bind_template_child(widget_class, PidginContactListWindow,
 	                                     sort_buddies);
-	gtk_widget_class_bind_template_child(widget_class, PidginContactList,
+	gtk_widget_class_bind_template_child(widget_class, PidginContactListWindow,
 	                                     accounts);
-	gtk_widget_class_bind_template_child(widget_class, PidginContactList,
+	gtk_widget_class_bind_template_child(widget_class, PidginContactListWindow,
 	                                     accounts_menu);
 }
 
@@ -84,20 +84,20 @@
  * Public API
  *****************************************************************************/
 GtkWidget *
-pidgin_contact_list_new(void) {
-	return GTK_WIDGET(g_object_new(PIDGIN_TYPE_CONTACT_LIST, NULL));
+pidgin_contact_list_window_new(void) {
+	return g_object_new(PIDGIN_TYPE_CONTACT_LIST_WINDOW, NULL);
 }
 
 GtkWidget *
-pidgin_contact_list_get_vbox(PidginContactList *contact_list) {
-	g_return_val_if_fail(PIDGIN_IS_CONTACT_LIST(contact_list), NULL);
+pidgin_contact_list_window_get_vbox(PidginContactListWindow *window) {
+	g_return_val_if_fail(PIDGIN_IS_CONTACT_LIST_WINDOW(window), NULL);
 
-	return contact_list->vbox;
+	return window->vbox;
 }
 
 GtkWidget *
-pidgin_contact_list_get_menu_sort_item(PidginContactList *contact_list) {
-	g_return_val_if_fail(PIDGIN_IS_CONTACT_LIST(contact_list), NULL);
+pidgin_contact_list_window_get_menu_sort_item(PidginContactListWindow *window) {
+	g_return_val_if_fail(PIDGIN_IS_CONTACT_LIST_WINDOW(window), NULL);
 
-	return contact_list->sort_buddies;
+	return window->sort_buddies;
 }
diff --git a/pidgin/resources/BuddyList/window.ui b/pidgin/resources/BuddyList/window.ui
--- a/pidgin/resources/BuddyList/window.ui
+++ b/pidgin/resources/BuddyList/window.ui
@@ -26,7 +26,7 @@
   <!-- interface-name Pidgin -->
   <!-- interface-description Internet Messenger -->
   <!-- interface-copyright Pidgin Developers <devel@pidgin.im> -->
-  <template class="PidginContactList" parent="GtkApplicationWindow">
+  <template class="PidginContactListWindow" parent="GtkApplicationWindow">
     <property name="can-focus">False</property>
     <property name="title" translatable="yes">Contact List</property>
     <property name="role">contact_list</property>
diff --git a/po/POTFILES.in b/po/POTFILES.in
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -349,7 +349,7 @@
 pidgin/pidginclosebutton.c
 pidgin/pidgincolor.c
 pidgin/pidgincommands.c
-pidgin/pidgincontactlist.c
+pidgin/pidgincontactlistwindow.c
 pidgin/pidginconversationwindow.c
 pidgin/pidgindebug.c
 pidgin/pidgindialog.c

diff --git a/pidgin/pidgincontactlist.h b/pidgin/pidgincontactlistwindow.h
rename from pidgin/pidgincontactlist.h
rename to pidgin/pidgincontactlistwindow.h
--- a/pidgin/pidgincontactlist.h
+++ b/pidgin/pidgincontactlistwindow.h
@@ -24,8 +24,8 @@
 # error "only <pidgin.h> may be included directly"
 #endif
 
-#ifndef PIDGIN_CONTACT_LIST_H
-#define PIDGIN_CONTACT_LIST_H
+#ifndef PIDGIN_CONTACT_LIST_WINDOW_H
+#define PIDGIN_CONTACT_LIST_WINDOW_H
 
 #include <glib.h>
 
@@ -35,32 +35,32 @@
 
 
 /**
- * PidginContactList:
+ * PidginContactListWindow:
  *
  * #PidginContactList is a transitional widget as we slowly migrate it into the
  * conversation window to make a single window application.
  *
  * Since: 3.0.0
  */
 
-#define PIDGIN_TYPE_CONTACT_LIST (pidgin_contact_list_get_type())
-G_DECLARE_FINAL_TYPE(PidginContactList, pidgin_contact_list, PIDGIN,
-                     CONTACT_LIST, GtkApplicationWindow)
+#define PIDGIN_TYPE_CONTACT_LIST_WINDOW (pidgin_contact_list_window_get_type())
+G_DECLARE_FINAL_TYPE(PidginContactListWindow, pidgin_contact_list_window,
+                     PIDGIN, CONTACT_LIST_WINDOW, GtkApplicationWindow)
 
 /**
- * pidgin_contact_list_new:
+ * pidgin_contact_list_window_new:
  *
  * Creates a new #PidginContactList instance.
  *
  * Returns: (transfer full): The new #PidginContactList instance.
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_contact_list_new(void);
+GtkWidget *pidgin_contact_list_window_new(void);
 
 /**
- * pidgin_contact_list_get_vbox:
- * @contact_list: The #PidginContactList instance.
+ * pidgin_contact_list_window_get_vbox:
+ * @contact_list: The #PidginContactListWindow instance.
  *
  * Gets the main vbox for @contact_list.
  *
@@ -68,11 +68,11 @@
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_contact_list_get_vbox(PidginContactList *contact_list);
+GtkWidget *pidgin_contact_list_window_get_vbox(PidginContactListWindow *window);
 
 /**
- * pidgin_contact_list_get_menu_sort_item:
- * @contact_list: The #PidginContactList instance.
+ * pidgin_contact_list_window_get_menu_sort_item:
+ * @contact_list: The #PidginContactListWindow instance.
  *
  * Returns the sort menu item from the menu of @contact_list.
  *
@@ -80,11 +80,11 @@
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_contact_list_get_menu_sort_item(PidginContactList *contact_list);
+GtkWidget *pidgin_contact_list_window_get_menu_sort_item(PidginContactListWindow *window);
 
 /**
- * pidgin_contact_list_get_menu_tray:
- * @contact_list: The #PidginContactList instance.
+ * pidgin_contact_list_window_get_menu_tray:
+ * @contact_list: The #PidginContactListWindow instance.
  *
  * Gets the #PidginMenuTray instance from the menu of @contact_list.
  *
@@ -93,8 +93,8 @@
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_contact_list_get_menu_tray(PidginContactList *contact_list);
+GtkWidget *pidgin_contact_list_window_get_menu_tray(PidginContactListWindow *window);
 
 G_END_DECLS
 
-#endif /* PIDGIN_CONTACT_LIST_H */
+#endif /* PIDGIN_CONTACT_LIST_WINDOW_H */
@@ -35,32 +35,32 @@
  *
- * #PidginContactList is a transitional widget as we slowly migrate it into the
- * conversation window to make a single window application.
+ * #PidginContactListWindow is a transitional widget as we slowly migrate it
+ * into the conversation window to make a single window application.
  *
  * Since: 3.0.0
@@ -35,32 +35,32 @@
  *
- * Creates a new #PidginContactList instance.
+ * Creates a new #PidginContactListWindow instance.
  *
@@ -35,32 +35,32 @@
  *
- * Returns: (transfer full): The new #PidginContactList instance.
+ * Returns: (transfer full): The new #PidginContactListWindow instance.
  *
  * Since: 3.0.0